@@ -1,5 +1,7 @@
 from .EclipseCdtGenerator import eclipseCdtGenerator
 from .QtCreatorGenerator import qtProjectGenerator
+from .VisualStudioCode import vsCodeProjectGenerator
+from ..utils import isWindows
 import sys
 
 __all__ = ['generators']
@@ -7,8 +9,9 @@ __all__ = ['generators']
 generators = {
     'eclipseCdt' : eclipseCdtGenerator,
     'qt-creator' : qtProjectGenerator,
+    'vscode': vsCodeProjectGenerator
 }
 
-if sys.platform == 'win32' or sys.platform == 'msys':
+if isWindows():
     from .VisualStudio import vs2019ProjectGenerator
     generators['vs2019'] = vs2019ProjectGenerator
