@@ -4,7 +4,7 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from ..errors import BuildError
-from ..utils import removePath, isWindows, summonMagic
+from ..utils import removePath, isWindows, summonMagic, replacePath
 import argparse
 import os
 import re
@@ -324,9 +324,7 @@ class CommonIDEGenerator:
         for i in self.args.additional_includes:
             for e in parseArgumentLine(i):
                 if os.path.exists(e):
-                    for root, directories, filenames in os.walk(e):
-                        filterDirs(directories)
-                        self.appendIncludeDirectories.append(os.path.join(e,root))
+                    self.appendIncludeDirectories.append(e)
 
     def generate(self):
         if self.args.overwrite:
@@ -348,7 +346,7 @@ class CommonIDEGenerator:
             oldContent = None
 
         if oldContent != newContent:
-            os.replace(newName, name)
+            replacePath(newName, name)
             with open(oldName, "wb") as f:
                 f.write(newContent)
         else:
