@@ -5,6 +5,7 @@
 
 from .errors import ParseError
 from .tty import colorize, WarnOnce, WARNING
+from .utils import replacePath
 import copy
 import errno
 import os
@@ -162,13 +163,16 @@ class _BobState():
                 "createdWithVersion" : self.__createdWithVersion,
                 "storagePath" : self.__storagePath,
             }
+            self.__dirty = False
             try:
-                with open(self.__uncommittedPath, "wb") as f:
+                # Atomically replace the last uncommitted state.
+                dirtyPath = self.__uncommittedPath + ".dirty"
+                with open(dirtyPath, "wb") as f:
                     with DigestAdder(f) as df:
                         pickle.dump(state, df)
+                replacePath(dirtyPath, self.__uncommittedPath)
             except OSError as e:
                 raise ParseError("Error saving workspace state: " + str(e))
-            self.__dirty = False
         else:
             self.__dirty = True
 
@@ -185,7 +189,7 @@ class _BobState():
                     commit = (csum == data[-4:])
                 os.fsync(f.fileno())
             if commit:
-                os.replace(self.__uncommittedPath, self.__path)
+                replacePath(self.__uncommittedPath, self.__path)
                 return
             else:
                 print(colorize("Warning: discarding corrupted workspace state!", WARNING),
